Skip to main contentCrate bdb_parser
Source pub use parsers::parse_track_database;pub use models::*;
- models
- This module contains the data structures and enums used to represent the parsed data.
- parsers
- This module contains the parsing functions for the file format.