pub struct TrackChunk {
pub track_name: String,
pub bounding_box: BoundingBox,
pub start_finish: StartFinish,
pub combo: bool,
}Expand description
All the data for a single track.
Fields
track_name: StringThe name of the track.
bounding_box: BoundingBoxThe bounding box of the track.
start_finish: StartFinishThe start and finish of the track.
combo: boolWhether the track is a combo track (Not sure exactly what this is but there is a flag set for every track that has “combo” in the name.)