pub fn parse_track_database(input: &[u8]) -> IResult<&[u8], TrackDatabase>Expand description
This is the top level parsing function that accepts the entire file and returns a TrackDatabase.
pub fn parse_track_database(input: &[u8]) -> IResult<&[u8], TrackDatabase>This is the top level parsing function that accepts the entire file and returns a TrackDatabase.